import 'package:flutter/services.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:dvote/dvote.dart';
import 'package:dvote/api/entity.dart';
import 'package:dvote/api/file.dart';
import 'package:dvote/util/content-uri.dart';

void main() {
  hdWallet();
  vocGateway();
  web3Gateway();
}

void hdWallet() {
  const MethodChannel channel = MethodChannel('dvote');

  setUp(() {
    channel.setMockMethodCallHandler((MethodCall methodCall) async {
      return '0xbf0177fac1aad0cba87e5c0f54742fae36d69fff';
    });
  });

  tearDown(() {
    channel.setMockMethodCallHandler(null);
  });

  test('mnemonicToAddress', () async {
    expect(
        await Dvote.mnemonicToAddress(
            'master lift organ scale accuse under head grace deny panic apart check',
            hdPath: "m/44'/60'/0'/0/0"),
        '0xbf0177fac1aad0cba87e5c0f54742fae36d69fff');
  });
}

void vocGateway() {
  final origin = "ipfs://Qmaisz6NMhDB51cCvNWa1GMS7LU1pAxdF4Ld6Ft9kZEP2a";
  final gwUri = "ws://gateway:2082/dvote";
  final publicKey =
      "02325f284f50fa52d53579c7873a480b351cc20f7780fa556929f5017283ad2449";

  test('fetchFile', () async {
    final res = await fetchFileString(ContentURI(origin), gwUri,
        gatewayPublicKey: publicKey);
    expect(res, "Hello from IPFS Gateway Checker\n");
  });
}

void web3Gateway() {
  test('web3Gateway', () async {
    final result = await fetchEntity(
      "0x180dd5765d9f7ecef810b565a2e5bd14a3ccd536c442b3de74867df552855e85",
      "0x0dCA233CE5152d58c74E74693A3C496D01542244",
      "ws://gateway:2082/dvote",
      "http://gateway:2086/web3",
      networkId: "1234",
      entryPoints: [],
    );

    print(result.toJson());
  });
}
